Learn R Programming

echarts4r (version 0.5.0)

e_graphic_g: Graphic

Description

Low level API to define graphic elements.

Usage

e_graphic_g(e, ...)

e_group_g(e, ...)

e_image_g(e, ...)

e_text_g(e, ...)

e_rect_g(e, ...)

e_circle_g(e, ...)

e_ring_g(e, ...)

e_sector_g(e, ...)

e_arc_g(e, ...)

e_polygon_g(e, ...)

e_polyline_g(e, ...)

e_line_g(e, ...)

e_bezier_curve_g(e, ...)

Arguments

e

An echarts4r object as returned by e_charts or a proxy as returned by echarts4rProxy.

...

Any other option to pass, check See Also section.

Functions

  • e_graphic_g to initialise graphics, entirely optional.

  • e_group_g to create group, the children of which will share attributes.

  • e_image_g to a png or jpg image.

  • e_text_g to add text.

  • e_rect_g to add a rectangle.

  • e_circle_g to add a circle.

  • e_ring_g to add a ring.

  • e_sector_g

  • e_arc_g to create an arc.

  • e_polygon_g to create a polygon.

  • e_polyline_g to create a polyline.

  • e_line_g to draw a line.

  • e_bezier_curve_g to draw a quadratic bezier curve or cubic bezier curve.

Examples

Run this code
# may not work in RStudio viewer
# Open in browser
cars |>
  e_charts(speed) |>
  e_scatter(dist) |>
  e_image_g(
    right = 20,
    top = 20,
    z = -999,
    style = list(
      image = "https://www.r-project.org/logo/Rlogo.png",
      width = 150,
      height = 150,
      opacity = .6
    )
  )

anno_text <-
'xAxis represents miles per gallon, yAxis represents weight in tonnes.'
# Position does change depending on window size.
mtcars |>
  e_charts(mpg) |>
  e_line(wt) |>
  e_group_g(
    left = '18%',
    top = '55%',
    children = list(
      # Background rectangle
      list(
        type = 'rect',
        z = 100,
        left = 'center',
        top = 'middle',
        shape = list(
          width = 240,
          height = 70
        ),
        style = list(
          fill = '#fff',
          stroke = '#555',
          lineWidth = 1,
          shadowBlur = 8,
          shadowOffsetX = 3,
          shadowOffsetY = 3,
          shadowColor = 'rgba(0,0,0,0.2)'
        )
      ),
      # Text element
      list(
        type = 'text',
        z = 100,
        left = 'center',
        top = 'middle',
        style = list(
          fill = '#333',
          width = 220,
          overflow = 'break',
          text = anno_text,
          font = '14px Microsoft YaHei'
        )
      )
    )
  )
#' @seealso \href{https://echarts.apache.org/en/option.html#graphic}{official documentation}

Run the code above in your browser using DataLab