powered by
Draw segmented doughnut.
e_doughnut( e, numerator = NULL, denominator = NULL, formatter = "{c}/{b}", fontSize = "10em", fontColor = "#555", center = c("50%", "50%"), radius = c("50%", "65%"), rm_x = TRUE, rm_y = TRUE, ... )
An echarts4r object as returned by e_charts or a proxy as returned by echarts4rProxy.
echarts4r
e_charts
echarts4rProxy
numeraetor to provide filled segments and denominator for total segments.
javascript string formatter for center text of chart.
font values for center text of chart.
center provides relative position of the center of chart while radius provides the radius of your circle for outer segments.
Whether to remove x and y axis, defaults to TRUE.
TRUE
Any other option to pass, check See Also section.
official documentation
e_chart() |> e_doughnut(numerator = 3, denominator = 6)
Run the code above in your browser using DataLab