powered by
Initialise geo.
e_geo(e, map = "world", ..., rm_x = TRUE, rm_y = TRUE)
An echarts4r object as returned by e_charts or a proxy as returned by echarts4rProxy.
echarts4r
e_charts
echarts4rProxy
Map type.
Any other option to pass, check See Also section.
Whether to remove x and y axis, defaults to TRUE.
TRUE
Additional arguments
flights |> e_charts() |> e_geo() |> e_lines( start_lon, start_lat, end_lon, end_lat, name = "flights", lineStyle = list(normal = list(curveness = 0.3)) )
Run the code above in your browser using DataLab