Learn R Programming

echarts4r (version 0.0.1.9000)

e_tooltip: Tooltip

Description

Customise tooltip

Usage

e_tooltip(e, show = TRUE, trigger = c("item", "axis"),
  show.content = TRUE, trigger.on = c("mousemove|click", "mousemove",
  "click"), show.delay = 0, hide.delay = 100, enterable = TRUE,
  confine = FALSE, transition.duration = 0.4, always.show.content = FALSE,
  ...)

Arguments

e

An echarts4r object as returned by e_charts.

show

Set to FALSE to hide the tooltip.

trigger

Type of triggering, item or axis.

show.content

Whether to show the tooltip floating layer.

trigger.on

Conditions to trigger tooltip; mousemove|click, mousemove, or click.

show.delay

Delay time for showing tooltip, in millisecond.

hide.delay

Delay time for hiding tooltip, in ms. It will be invalid when always.show.content is true.

enterable

Whether mouse is allowed to enter the floating layer of tooltip. If you need to interact in the tooltip like with links or buttons, it can be set as TRUE.

confine

Whether tooltip content in the view rect of chart instance.

transition.duration

The transition duration of tooltip's animation, in seconds.

always.show.content

Whether to show tooltip content all the time. By default, it will be hidden after some time. It can be set to be TRUE to preserve displaying.

...

Any other option to pass, check See Also section.

See Also

https://ecomfe.github.io/echarts-doc/public/en/option.html#tooltip

Examples

Run this code
# NOT RUN {
USArrests %>% 
  e_charts(Assault) %>% 
  e_bar(Murder) %>% 
  e_tooltip(trigger = "axis")

# }

Run the code above in your browser using DataLab