Conditions to trigger tooltip; mousemove|click, mousemove,
or click.
show.delay
Delay time for showing tooltip, in millisecond.
hide.delay
Delay time for hiding tooltip, in ms. It will be invalid when
always.show.content is true.
enterable
Whether mouse is allowed to enter the floating layer of tooltip.
If you need to interact in the tooltip like with links or buttons, it can be set as TRUE.
confine
Whether tooltip content in the view rect of chart instance.
transition.duration
The transition duration of tooltip's animation, in seconds.
always.show.content
Whether to show tooltip content all the time. By default,
it will be hidden after some time. It can be set to be TRUE to preserve displaying.