if_style_is_not_none: Determine if first element is none, then no style
The first element could be NULL, a style, or a vector so we must account for all these.
style = NULL
style = list(lineWidth = 5)
style = list(shape = list(width = 100))
Description
Determine if first element is none, then no style
The first element could be NULL, a style, or a vector so we must account for all these.
style = NULL
style = list(lineWidth = 5)
style = list(shape = list(width = 100))